@@ -62,16 +62,14 @@ test_that("returned classes", {
 
 data(lsat)
 test_that("excercise all indices", {
-            expect_is(sp <- spectralIndices(lsat, blue = 1, green=2, red=3, nir=4, swir2=5, swir3=7,
+            expect_is(sp <- spectralIndices(lsat, blue = 1, green=2, redEdge1=1, redEdge2=2, redEdge3=3, red=3, nir=4, swir2=5, swir3=7,
                             coefs = list(L=0.4,s=0.3,swir2ccc=30,swir2coc=140), scaleFactor=255), "RasterBrick")
-            expect_equal(nlayers(sp), 23)
+            expect_equal(nlayers(sp), length(.IDXdb))
         })
 
 
 
 
-
-
 ## Check for duplicate indices
 #tmat <- do.call(rbind, lapply(1:ncol(k), function(i){colSums(k[,i]-k, na.rm = T)==0}))
 #colnames(tmat) <- rownames(tmat) <- colnames(k)
